## Arches Controlled Lists 1.0.1 Release Notes

### Bug Fixes and Enhancements

- Fix issue with migrating complex polyhierarchies from the RDM [#190](https://github.com/archesproject/arches-controlled-lists/issues/190)
- Use concept identifiers as URIs during RDM to Controlled Lists migration [#96](https://github.com/archesproject/arches-controlled-lists/issues/96)
- Fix reference datatype label lookup for multiple labels and labels with commas [#189](https://github.com/archesproject/arches-controlled-lists/issues/189)

### Installation

1. If this is your first time installing Arches Controlled Lists:
    ```
    pip install arches-controlled-lists==1.0.1
    ```
    and build your front-end
    ```
    npm install
    npm run build_development
    python manage.py collectstatic
    ```

### Upgrading

1. If you have already installed, Arches Controlled-Lists:
    ```
    pip install --upgrade arches-controlled-lists==1.0.1
    ```

### Finally...
1. If you are running Arches on Apache, restart your server:
    ```
    sudo service apache2 reload
    ```
